@@ -394,6 +394,8 @@ def generate_tsv_from_jams(
 def generate_files_from_jams(
     list_jams,
     out_folder,
+    fg_path=None,
+    bg_path=None,
     out_folder_jams=None,
     save_isolated_events=False,
     overwrite_exist_audio=False,
@@ -404,6 +406,8 @@ def generate_files_from_jams(
     Args:
         list_jams: list, list of jams filepath generated by Scaper.
         out_folder: str, output path to save audio files.
+        fg_path: str, the path to the foreground events, if not specified, should match what specified in the JAMS.
+        bg_path: str, the path to the background events, if not specified, should match what specified in the JAMS.
         out_folder_jams: str, path to write the jams (could be modified by fg_path and bg_path for example),
             if None, jams not saved
         save_isolated_events: bool, whether or not to save isolated events in a separate folder
@@ -428,6 +432,8 @@ def generate_files_from_jams(
             generate_from_jams(
                 jam_file,
                 audiofile,
+                fg_path=fg_path,
+                bg_path=bg_path,
                 jams_outfile=jams_outfile,
                 save_isolated_events=save_isolated_events,
                 **kwargs,
